@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.18 2000/05/11 09:03:14 fredgo Exp $
+# $Id: Document.py,v 1.18.2.2 2000/06/13 09:07:59 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -235,8 +235,12 @@ class Document (Connector.Publisher):
             entries = self.data.keys ()
 
         url = Fields.URL (style)
-        
-        Pyblio.Style.Utils.generate (url, format, self.data, entries, file)
+
+        try:
+            Pyblio.Style.Utils.generate (url, format, self.data, entries, file)
+        except RuntimeError, err:
+            print err
+            self.w.error (_("Error while parsing `%s':\n%s") % (style, err))
         return
 
 
@@ -463,7 +467,7 @@ class Document (Connector.Publisher):
                                       
     def close_document (self, * arg):
         self.issue ('close-document', self)
-        return
+        return 1
 
 
     def close_document_request (self):
