@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.17 2000/04/18 08:46:29 fredgo Exp $
+# $Id: Editor.py,v 1.18.2.1 2000/06/13 08:32:57 fredgo Exp $
 
 import string, re
 from gnome.ui import *
@@ -374,6 +374,8 @@ class Reference (BaseField):
         reflist = []
         for k in keys:
             (base, key) = string.split (k, '\0')
+            if not base: base = None
+            
             reflist.append (Key.Key (base, key))
 
         self.current = Fields.Reference (reflist)
@@ -570,9 +572,12 @@ class RealEditor (Connector.Publisher):
 
     def create_field (self, * arg):
         widget = self.newfield.gtk_entry ()
-        text = string.strip (string.lower (widget.get_text ()))
+        text   = string.strip (string.lower (widget.get_text ()))
         if text == '': return
 
+        # update the current entry
+        self.entry = self.update (self.database, copy.deepcopy (self.entry))
+
         newtype = Types.get_field (text).type
         self.entry [text] = newtype (_newcontent [newtype])
         self.update_notebook ()
