@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: FileSelector.py,v 1.3 2000/03/23 14:29:15 fredgo Exp $
+# $Id: FileSelector.py,v 1.4.2.1 2000/06/13 08:32:57 fredgo Exp $
 
 import string, os, urlparse, gettext
 
@@ -38,18 +38,21 @@ class URLFileSelection (GtkFileSelection):
     ''' Extended file selection dialog, with an URL field and a type
     selector. '''
     
-    def __init__(self, title = _("File"), url=TRUE, modal=TRUE, has_auto=TRUE):
+    def __init__(self, title = _("File"),
+                 url=TRUE, modal=TRUE, has_auto=TRUE,
+                 directory = None):
         
         GtkFileSelection.__init__(self)
         self.set_title (title)
-
+        self.hide_fileop_buttons ()
+        
         self.connect('destroy', self.quit)
         self.connect('delete_event', self.quit)
         self.cancel_button.connect('clicked', self.quit)
         self.ok_button.connect('clicked', self.ok_cb)
 
-        if modal:
-            grab_add (self)
+        if directory: self.set_filename (directory)
+        if modal:     grab_add (self)
 
         self.ret = None
         self.url = None
@@ -133,6 +136,6 @@ class URLFileSelection (GtkFileSelection):
     def run (self):
         self.show_all ()
         mainloop ()
-        
+
         return (self.ret, self.type)
 
